==> siddhi-core-3.2.9-sources.jar: org/wso2/siddhi/core/executor/condition/compare/equal/EqualCompareConditionExpressionExecutorBoolBool.java <==
/*
 * Copyright (c) 2015, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * WSO2 Inc. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.wso2.siddhi.core.executor.condition.compare.equal;

import org.wso2.siddhi.core.executor.ExpressionExecutor;

public class EqualCompareConditionExpressionExecutorBoolBool extends EqualCompareConditionExpressionExecutor {
    public EqualCompareConditionExpressionExecutorBoolBool(ExpressionExecutor leftExpressionExecutor,
                                                           ExpressionExecutor rightExpressionExecutor) {
        super(leftExpressionExecutor, rightExpressionExecutor);
    }


    @Override
    protected Boolean execute(Object left, Object right) {
        return ((Boolean) left).booleanValue() == ((Boolean) right).booleanValue();
    }

    @Override
    public ExpressionExecutor cloneExecutor(String key) {
        return new EqualCompareConditionExpressionExecutorBoolBool(leftExpressionExecutor.cloneExecutor(key), rightExpressionExecutor.cloneExecutor(key));
    }
}

==> siddhi-core-4.2.14-sources.jar: org/wso2/siddhi/core/executor/condition/compare/equal/EqualCompareConditionExpressionExecutorBoolBool.java <==
/*
 * Copyright (c) 2016, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * WSO2 Inc. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.wso2.siddhi.core.executor.condition.compare.equal;

import org.wso2.siddhi.core.executor.ExpressionExecutor;

/**
 * Executor class for Boolean-Boolean Equal condition. Condition evaluation logic is implemented within executor.
 */
public class EqualCompareConditionExpressionExecutorBoolBool extends EqualCompareConditionExpressionExecutor {
    public EqualCompareConditionExpressionExecutorBoolBool(ExpressionExecutor leftExpressionExecutor,
                                                           ExpressionExecutor rightExpressionExecutor) {
        super(leftExpressionExecutor, rightExpressionExecutor);
    }


    @Override
    protected Boolean execute(Object left, Object right) {
        return ((Boolean) left).booleanValue() == ((Boolean) right).booleanValue();
    }

    @Override
    public ExpressionExecutor cloneExecutor(String key) {
        return new EqualCompareConditionExpressionExecutorBoolBool(leftExpressionExecutor.cloneExecutor(key),
                rightExpressionExecutor.cloneExecutor(key));
    }
}
